<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Carmine D'Amore <carmine@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class DeleteButton
 * @package Pinpoint\V12Finance\Block\Adminhtml\Product\Edit
 */

namespace Pinpoint\V12Finance\Block\Adminhtml\Product\Edit;

use Magento\Backend\Block\Widget\Context;
use Magento\Framework\View\Element\UiComponent\Control\ButtonProviderInterface;

class DeleteButton implements ButtonProviderInterface
{
    /* @var \Magento\Framework\UrlInterface */
    protected $_urlBuilder;

    /* @var \Magento\Framework\App\RequestInterface */
    protected $_request;

    /**
     * Constructor
     *
     * @param \Magento\Backend\Block\Widget\Context $context
     */
    public function __construct(
        Context $context
    ) {
        $this->_request = $context->getRequest();
        $this->_urlBuilder = $context->getUrlBuilder();
    }

    /**
     * Delet button config
     *
     * @return array
     */
    public function getButtonData()
    {
        return [
            'label' => __('Delete Product'),
            'on_click' => "deleteConfirm('" . __('Are you sure you want to delete this finance product?') . "', '" . $this->getDeleteUrl() . "')",
            'class' => 'delete',
            'sort_order' => 20
        ];
    }

    /**
     * Get admin route for delete action
     *
     * @return string
     */
    public function getDeleteUrl()
    {
        return $this->getUrl('*/*/delete', ['id' => $this->_request->getParam('id', null)]);
    }

    /**
     * Generate url by route and parameters
     *
     * @param   string $route
     * @param   array $params
     * @return  string
     */
    public function getUrl($route = '', $params = [])
    {
        return $this->_urlBuilder->getUrl($route, $params);
    }
}
