<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Carmine D'Amore <carmine@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Import
 * @package Pinpoint\V12Finance\Controller\Adminhtml\System\Config
 */

namespace Pinpoint\V12Finance\Controller\Adminhtml\System\Config;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\Result\JsonFactory;
use Pinpoint\V12Finance\Helper\Data as V12Helper;
use Pinpoint\V12Finance\Logger\Logger as Logger;
use Pinpoint\V12Finance\Model\ProductFactory;
use Pinpoint\V12Finance\Model\ResourceModel\Product\CollectionFactory;
use Pinpoint\V12Finance\Model\Rest\Api\FinanceProductListRequest;

class Import extends Action
{
    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Pinpoint\V12Finance\Model\Rest\Api\FinanceProductListRequest
     */
    protected $_financeProductListRequest;

    /**
     * @var \Pinpoint\V12Finance\Logger\Logger
     */
    protected $_logger;

    /**
     * @var \Pinpoint\V12Finance\Model\ProductFactory
     */
    protected $_financeProduct;

    /**
     * @var \Pinpoint\V12Finance\Helper\Data
     */
    protected $_helper;

    /**
     * @var CollectionFactory
     */
    protected $_financeProductCollection;

    /**
     * @param Context $context
     * @param JsonFactory $resultJsonFactory
     * @param FinanceProductListRequest $financeProductListRequest
     * @param V12Helper $helper
     * @param ProductFactory $financeProduct
     * @param CollectionFactory $productCollection
     * @param Logger $logger
     */
    public function __construct(
        Context $context,
        JsonFactory $resultJsonFactory,
        FinanceProductListRequest $financeProductListRequest,
        V12Helper $helper,
        ProductFactory $financeProduct,
        CollectionFactory $productCollection,
        Logger $logger
    ) {
        parent::__construct($context);
        $this->resultJsonFactory = $resultJsonFactory;
        $this->_helper = $helper;
        $this->_logger = $logger;
        $this->_financeProduct = $financeProduct;
        $this->_financeProductCollection = $productCollection;
        $this->_financeProductListRequest = $financeProductListRequest;
    }

    /**
     * Import available V12 finance products via API. Update existing, create new, deactivate no longer existing
     *
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {
       // try {
            if ($financeProducts = $this->_financeProductListRequest->getFinanceProducts()) {
                $validGuids = [];

                foreach ($financeProducts as $apiProduct) {
                    $financeProduct = $this->_financeProduct->create()->load($apiProduct['ProductGuid'], 'guid');
                    if (!$financeProduct->getId()) {
                        $financeProduct = $this->_financeProduct->create();
                    }

                    $financeProduct->setApr($apiProduct['APR']);
                    $financeProduct->setCalcFactor($apiProduct['CalculationFactor']);
                    $financeProduct->setDeferredPeriod($apiProduct['DeferredPeriod']);
                    $financeProduct->setDescription($apiProduct['Description']);
                    $financeProduct->setDocumentFee($apiProduct['DocumentFee']);
                    $financeProduct->setDocumentFeeCollectionMonth($apiProduct['DocumentFeeCollectionMonth']);
                    $financeProduct->setDocumentFeeMaximum($apiProduct['DocumentFeeMaximum']);
                    $financeProduct->setDocumentFeeMinimum($apiProduct['DocumentFeeMinimum']);
                    $financeProduct->setDocumentFeePercentage($apiProduct['DocumentFeePercentage']);
                    $financeProduct->setMaxLoan($apiProduct['MaxLoan']);
                    $financeProduct->setMinLoan($apiProduct['MinLoan']);
                    $financeProduct->setMonthlyRate($apiProduct['MonthlyRate']);
                    $financeProduct->setMonths($apiProduct['Months']);
                    $financeProduct->setName($apiProduct['Name']);
                    $financeProduct->setOptionPeriod($apiProduct['OptionPeriod']);
                    $financeProduct->setGuid($apiProduct['ProductGuid']);
                    $financeProduct->setProductId($apiProduct['ProductId']);
                    $financeProduct->setServiceFee($apiProduct['ServiceFee']);
                    $financeProduct->setSettlementFee($apiProduct['SettlementFee']);
                    $financeProduct->setTag($apiProduct['Tag']);

                    $financeProduct->save();

                    $validGuids[] = $apiProduct['ProductGuid'];
                }

                //Check for products no longer available via API, that are not deactive, and deactivate.
                $productCollection = $this->_financeProductCollection->create();
                $productCollection->addActiveFilter(0);
                //will not work :(
                //$productCollection->addFieldToFilter('guid', array('nin', $validGuids));
                $deactivatedProducts = 0;
                foreach ($productCollection as $_product) {
                    if (!in_array($_product->getGuid(), $validGuids)) {
                        $_product->setActive(0)->save();
                        $deactivatedProducts++;
                    }
                }

                $response['status'] = 'success';
                $response['message'] = __(count($financeProducts) . ' V12Finance products imported/updated. ' . $deactivatedProducts . ' de-activated.');
            } else {
                $response['status'] = 'success';
                $response['message'] = __('No V12 Finance products found for import.');
            }
//        } catch (\Exception $e) {
//            $this->_logger->critical('V12Finance GetRetailerFinanceProducts API Request', ['exception' => $e]);
//            $response['message'] = __('Could not retrieve V12Finance products list. [ERROR: ' . $e->getMessage() . ']');
//        }

        $result = $this->resultJsonFactory->create();
        return $result->setData($response);
    }

    /**
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_V12Finance::config');
    }
}
