<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Carmine D'Amore <carmine@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Config
 * @package Pinpoint\V12Finance\Helper
 */

namespace Pinpoint\V12Finance\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\DataObjectFactory;

class Config extends AbstractHelper
{
    /**
     * @var string
     */
    const CONFIG_PATH_RETAILER_GUID = 'payment/ppdv12finance/apiconfig/retailer_guid';

    /**
     * @var string
     */
    const CONFIG_PATH_RETAILER_ID = 'payment/ppdv12finance/apiconfig/retailer_id';

    /**
     * @var string
     */
    const CONFIG_PATH_AUTH_KEY = 'payment/ppdv12finance/apiconfig/auth_key';

    /**
     * @var string
     */
    const CONFIG_PATH_WSDL_URL = 'payment/ppdv12finance/apiconfig/wsdl';

    /**
     * @var string
     */
    const CONFIG_PATH_LOC_URL = 'payment/ppdv12finance/apiconfig/location';

    /**
     * @var string
     */
    const CONFIG_PATH_GATEW_URL = 'payment/ppdv12finance/apiconfig/gateway';

    /**
     * @var string
     */
    const CONFIG_PATH_RETURN_URL = 'payment/ppdv12finance/apiconfig/returnurl';

    /**
     * @var string
     */
    const CONFIG_PATH_ORDER_STATUS = 'payment/ppdv12finance/statusconfig/%s';

    /**
     * Config constructor.
     * @param DataObjectFactory $objectFactory
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        DataObjectFactory $objectFactory,
        \Magento\Framework\App\Helper\Context $context
    ) {
        parent::__construct($context);
        $this->_objectFactory = $objectFactory;
    }

    /**
     * @param mixed|null $store
     * @return string
     */
    public function getRetailerId($store = null)
    {
        return $this->scopeConfig->getValue(
            self::CONFIG_PATH_RETAILER_ID,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $store
        );
    }

    /**
     * @param mixed|null $store
     * @return string
     */
    public function getRetailerGuid($store = null)
    {
        return $this->scopeConfig->getValue(
            self::CONFIG_PATH_RETAILER_GUID,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $store
        );
    }

    /**
     * @param mixed|null $store
     * @return string
     */
    public function getAuthKey($store = null)
    {
        return $this->scopeConfig->getValue(
            self::CONFIG_PATH_AUTH_KEY,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $store
        );
    }

    /**
     * @param mixed|null $store
     * @return string
     */
    public function getWsdlUrl($store = null)
    {
        return $this->scopeConfig->getValue(
            self::CONFIG_PATH_WSDL_URL,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $store
        );
    }

    /**
     * @param mixed|null $store
     * @return string
     */
    public function getLocationUrl($store = null)
    {
        return $this->scopeConfig->getValue(
            self::CONFIG_PATH_LOC_URL,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $store
        );
    }

    /**
     * @param string $requestMethod
     * @return string
     */
    public function getGatewayUrl($requestMethod = '')
    {
        return $this->scopeConfig->getValue(
                self::CONFIG_PATH_GATEW_URL,
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE
            ) . $requestMethod;
    }

    /**
     * @return string
     */
    public function getReturnUrl()
    {
        return $this->scopeConfig->getValue(
            self::CONFIG_PATH_RETURN_URL,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return array
     */
    public function getRetailerAuth()
    {
        return [
            'AuthenticationKey' => $this->getAuthKey(),
            'RetailerGuid' => $this->getRetailerGuid(),
            'RetailerId' => $this->getRetailerId()
        ];
    }

    /**
     * @param $status
     * @return mixed
     */
    public function getOrderStatus($status)
    {
        return $this->scopeConfig->getValue(
            sprintf(self::CONFIG_PATH_ORDER_STATUS, strtolower($status)),
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }
}
