<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Carmine D'Amore <carmine@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Customer
 * @package Pinpoint\V12Finance\Model\Rest\Api
 */

namespace Pinpoint\V12Finance\Model\Rest\Api;

use Magento\Framework\Serialize\Serializer\Json;
use Pinpoint\V12Finance\Helper\Data as V12Helper;
use Pinpoint\V12Finance\Logger\Logger as Logger;

class Customer extends ApiAbstract
{
    /**
     * @var Address
     */
    protected $_apiAddress;

    /**
     * Customer constructor.
     * @param V12Helper $helper
     * @param Address $address
     * @param Logger $logger
     * @param \Magento\Framework\HTTP\Client\Curl $curl
     * @param Json $json
     */
    public function __construct(
        V12Helper $helper,
        Address $address,
        Logger $logger,
        \Magento\Framework\HTTP\Client\Curl $curl,
        Json $json
    ) {
        parent::__construct($helper, $logger, $curl, $json);
        $this->_apiAddress = $address;
    }

    /**
     * @param $order
     * @return array
     */
    public function fromMageCustomer($order)
    {
        $billingAddress = $order->getBillingAddress()->getData();
        $telephone = $billingAddress['telephone'];

        $data = [
            "customerId"        => $order->getCustomerId(),
            "EmailAddress"      => $order->getCustomerEmail(),
            "FirstName"         => $order->getCustomerFirstname(),
            "LastName"          => $order->getCustomerLastname(),
            "Hometelephone"     => [
                "Code" => substr($telephone, 0, 5),
                "Number" => substr($telephone, 5),
            ]
        ];

        return $data;
    }

    /**
     * @param
     */
    protected function _addAddress($address)
    {
        if (!isset($this->Addresses)) {
            $this->Addresses = [];
        }

        $this->Addresses[] = $address;
    }
}
