<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Carmine D'Amore <carmine@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Order
 * @package Pinpoint\V12Finance\Model\Rest\Api
 */

namespace Pinpoint\V12Finance\Model\Rest\Api;

use Magento\Framework\Serialize\Serializer\Json;
use Pinpoint\V12Finance\Helper\Data as V12Helper;
use Pinpoint\V12Finance\Logger\Logger as Logger;
use Pinpoint\V12Finance\Model\ProductFactory;

class Order extends ApiAbstract
{
    /**
     * @var OrderLine
     */
    protected $_orderLine;

    /**
     * @var ProductFactory
     */
    protected $_financeProduct;

    /**
     * Order constructor.
     * @param V12Helper $helper
     * @param Logger $logger
     * @param \Magento\Framework\HTTP\Client\Curl $curl
     * @param ProductFactory $financeProduct
     * @param OrderLine $orderLine
     * @param Json $json
     */
    public function __construct(
        V12Helper $helper,
        Logger $logger,
        \Magento\Framework\HTTP\Client\Curl $curl,
        ProductFactory $financeProduct,
        OrderLine $orderLine,
        Json $json
    ) {
        parent::__construct($helper, $logger, $curl, $json);

        $this->_financeProduct = $financeProduct;
        $this->_orderLine = $orderLine;
    }

    /**
     * @param $order
     * @return array
     */
    public function fromMageOrder($order)
    {
        $payment = $order->getPayment();
        $info = $payment->getMethodInstance()->getInfoInstance();

        $v12financeProductId = $info->getAdditionalInformation('v12finance_product_id');
        $v12financeDepositAmount = $info->getAdditionalInformation('v12finance_deposit_amount');

        $v12Product = $this->_financeProduct->create()->load($v12financeProductId, 'product_id');

        $requestData = [
                "CashPrice"         => (string) $order->getBaseGrandTotal(),
                "Deposit"           => (string) $v12financeDepositAmount,
                "DuplicateSalesReferenceMethod" => "ShowError",
                "Lines"             => [],
                "ProductId"         => $v12Product->getProductId(),
                "ProductGuid"       => $v12Product->getGuid(),
                "SalesReference"    => $order->getIncrementId(),
                "vLink"             => "false",
        ];

        foreach ($order->getAllItems() as $orderItem) {
            if ($orderItem->getParent()) {
                continue;
            }
            $orderLine = $this->_orderLine->fromMageOrderItem($orderItem);
            $requestData['Lines'][] = $orderLine;
        }

        $orderLine = $this->_addOrderLineForShipping($order);
        $requestData['Lines'][] = $orderLine;

        return $requestData;
    }

    /**
     * @param $order
     * @return array
     */
    protected function _addOrderLineForShipping($order)
    {
        $data = [
            "Item"  => __("Shipping"),
            "Price" => $this->_helper->formatPrice($order->getBaseShippingAmount() + $order->getBaseShippingTaxAmount()),
            "Qty"   => 1,
            "SKU"   => "SHIPPING",
        ];

        return $data;
    }
}
