<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Carmine D'Amore <carmine@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class AfterCancel
 * @package Pinpoint\V12Finance\Observer\Sales\Order
 */

namespace Pinpoint\V12Finance\Observer\Sales\Order;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Message\ManagerInterface;
use Psr\Log\LoggerInterface;

class AfterCancel implements ObserverInterface
{

    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $_logger;

    /**
     * @var \Magento\Framework\Message\ManagerInterface
     */
    protected $_messageManager;

    /**
     * AfterCancel constructor.
     * @param Session $session
     * @param LoggerInterface $logger
     */
    public function __construct(
        ManagerInterface $messageManager,
        LoggerInterface $logger
    ) {
        $this->_messageManager = $messageManager;
        $this->_logger = $logger;
    }

    /**
     * @param Observer $observer
     * @return $this
     */
    public function execute(Observer $observer)
    {
        $order = $observer->getOrder();

        if ($order->getPayment()->getMethod() === \Pinpoint\V12Finance\Model\Payment\Method\V12Finance::CODE) {
            try {
                // Send API Update request
                $method = $order->getPayment()->getMethodInstance();
                //@todo cancel application
                //$method->doUpdateApplicationRequest($order, C3_V12Finance_Model_Payment::APPLICATION_UPDATE_TYPE_CANCEL);
                $order->getPayment()->save();
            } catch (\Exception $e) {
                $this->_messageManager->addError(__('V12 Finance payment request could not be sent.'));
            }
        }

        return $this;
    }
}
