/**
 * Copyright © 2013-2017 Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
/*browser:true*/
/*global define*/
define(
    [
        'underscore',
        'Magento_Checkout/js/view/payment/default',
        'mage/translate',
        'jquery'
    ],
    function (_, Component, $t, $) {
        'use strict';

        return Component.extend({

            defaults: {
                v12financeProductId: '',
                v12financeProductTitle: '',
                v12financeDeposit: 0,
                recalcTimeout : null
            },

            /**
             * Init component
             */
            initialize: function () {
                var self = this;
                this._super();
                this.recalcHandler();
            },

            /**
             * Get code
             * @returns {String}
             */
            getCode: function () {
                return window.checkoutConfig.payment.v12form.code;
            },

            /**
             * Get cart total
             * @returns {float}
             */
            getCartTotal: function () {
                return parseFloat(window.checkoutConfig.payment.v12form.cartTotal.replace(",",""));
            },

            /**
             * Get data
             * @returns {Object}
             */
            getData: function () {

                //Ensure mindeposit gets set if not edited on payment form
                //Otherwise defaults to 0
                this.v12financeDeposit = (this.v12financeDeposit > 0) ? this.v12financeDeposit  : this.getMinDeposit();

                return {
                    'method': this.item.method,
                    'additional_data': {
                        'product_title' : this.v12financeProductTitle,
                        'product_id': this.v12financeProductId,
                        'deposit_amount': this.v12financeDeposit
                    }
                };
            },

            /**
             * Get list of available finance products
             * @returns {Object}
             */
            getAvailableProducts: function () {
                return window.checkoutConfig.payment.v12form.availableProducts;
            },

            getCurrencySymbol: function (){
                return window.checkoutConfig.payment.v12form.currencySymbol;
            },

            /**
             * Get config field variable_deposit
             * @returns integer
             */
            getVariableDeposit: function () {
                return window.checkoutConfig.payment.v12form.variableDeposit;
            },

            /**
             * Get config field minimum_deposit_amount
             * @returns integer
             */
            getMinDeposit: function () {
                return window.checkoutConfig.payment.v12form.minDeposit;
            },

            /**
             * Get config field maximum_deposit_amount
             * @returns integer
             */
            getMaxDeposit: function () {
                return window.checkoutConfig.payment.v12form.maxDeposit;
            },

            /**
             * Is legend available to display
             * @returns {Boolean}
             */
            isShowLegend: function () {
                return false;
            },

            financeProductSelect: function (){

                var optionValue = $('select#v12_finance_option').val();
                var optionTitle = $('select#v12_finance_option:selected').text();

                $('#v12finance_product_container .finance_product_wrapper:visible').slideUp();
                $('#v12_deposit_wrapper:visible').slideUp();

                if(optionValue){
                    //Display finance info
                    $('#v12finance_product_container #v12finance_product_' + optionValue).slideDown();
                    $('#v12_deposit_wrapper').slideDown();

                    //save selection details
                    self.v12financeProductId = optionValue;
                    self.v12financeProductTitle = optionTitle;
                }else{
                    self.v12financeProductId = '';
                    self.v12financeProductTitle = '';
                }

            },

            recalcHandler: function () {

                if (this.recalcTimeout) {
                    clearTimeout(this.recalcTimeout);
                }

                var _self = this;
                this.recalcTimeout = setTimeout(function(){
                    _self.recalcFinanceOptions(_self);
                }, 600);

            },

            recalcFinanceOptions: function (_self) {

                var deposit = parseFloat($('input#v12finance_deposit').val());
                var mindeposit = _self.getMinDeposit();
                var maxdeposit = _self.getMaxDeposit();

                if(isNaN(deposit) || (deposit < mindeposit) || (deposit > maxdeposit)){
                    $('input#v12finance_deposit').val(mindeposit);
                }

                var cartTotal = _self.getCartTotal() - deposit;

                var loan = Math.round(cartTotal*100)/100;


                var products = this.getAvailableProducts();
                for(var index=0; index<products.length; index++){

                    var loanamount = loan.toFixed(2);

                    var id = products[index]['id'];
                    var productWrapper = $('#v12finance_product_' + id);
                    var apr = $('#v12_apr_' + id,productWrapper).html().replace('%','');
                    var months = parseInt($('#v12_month_' + id,productWrapper).html());

                    if(apr == 0){
                        var interest = 0;
                        var totalPayable = cartTotal;
                        var monthlyPayment = cartTotal/months;
                        monthlyPayment = Math.round(monthlyPayment*100)/100;
                    }
                    else {
                        var monthlyPayment = cartTotal * products[index]['calcFactor'];
                        monthlyPayment = Math.round(monthlyPayment*100)/100;
                        var interest = monthlyPayment * months;
                        var totalPayable = interest;
                        interest = interest - cartTotal;
                    }

                    totalPayable = totalPayable.toFixed(2);

                    interest = interest.toFixed(2);

                    monthlyPayment = monthlyPayment.toFixed(2);

                    $('#v12_monthlypayment_' + id,productWrapper).html(this.getCurrencySymbol() + monthlyPayment);
                    $('#v12_interest_' + id,productWrapper).html(this.getCurrencySymbol() + interest);
                    $('#v12_deposit_' + id,productWrapper).html(this.getCurrencySymbol() + deposit.toFixed(2));
                    $('#v12_total_payable_' + id,productWrapper).html(this.getCurrencySymbol() + totalPayable);

                    //Process description
                    var description = $('#copy_v12_description_' + id,productWrapper).html();
                    var updatedDescription = description.replace('$LOAN$',cartTotal.toFixed(2)).replace('$INSTALMENT$',monthlyPayment).replace('$TERM$',months).replace('$TOTAL_PAYABLE$',totalPayable).replace('$CHARGE_FOR_CREDIT$',interest).replace('$APR$',apr);
                    $('#v12_description_' + id,productWrapper).html(updatedDescription);
                }

                _self.v12financeDeposit = deposit;

            }

        });
    }
);
